==> knative-model-6.5.1-sources.jar: io/fabric8/knative/serving/v1/RouteSpecFluent.java <==
package io.fabric8.knative.serving.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface RouteSpecFluent<A extends RouteSpecFluent<A>> extends Fluent<A>{
  public A addToTraffic(Integer index,TrafficTarget item);
  public A setToTraffic(Integer index,TrafficTarget item);
  public A addToTraffic(io.fabric8.knative.serving.v1.TrafficTarget... items);
  public A addAllToTraffic(Collection<TrafficTarget> items);
  public A removeFromTraffic(io.fabric8.knative.serving.v1.TrafficTarget... items);
  public A removeAllFromTraffic(Collection<TrafficTarget> items);
  public A removeMatchingFromTraffic(Predicate<TrafficTargetBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildTraffic instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<TrafficTarget> getTraffic();
  public List<TrafficTarget> buildTraffic();
  public TrafficTarget buildTraffic(Integer index);
  public TrafficTarget buildFirstTraffic();
  public TrafficTarget buildLastTraffic();
  public TrafficTarget buildMatchingTraffic(Predicate<TrafficTargetBuilder> predicate);
  public Boolean hasMatchingTraffic(Predicate<TrafficTargetBuilder> predicate);
  public A withTraffic(List<TrafficTarget> traffic);
  public A withTraffic(io.fabric8.knative.serving.v1.TrafficTarget... traffic);
  public Boolean hasTraffic();
  public RouteSpecFluent.TrafficNested<A> addNewTraffic();
  public RouteSpecFluent.TrafficNested<A> addNewTrafficLike(TrafficTarget item);
  public RouteSpecFluent.TrafficNested<A> setNewTrafficLike(Integer index,TrafficTarget item);
  public RouteSpecFluent.TrafficNested<A> editTraffic(Integer index);
  public RouteSpecFluent.TrafficNested<A> editFirstTraffic();
  public RouteSpecFluent.TrafficNested<A> editLastTraffic();
  public RouteSpecFluent.TrafficNested<A> editMatchingTraffic(Predicate<TrafficTargetBuilder> predicate);
  public interface TrafficNested<N> extends Nested<N>,TrafficTargetFluent<RouteSpecFluent.TrafficNested<N>>{
    public N and();
    public N endTraffic();
    
  }
  
}

==> knative-model-6.7.1-sources.jar: io/fabric8/knative/serving/v1/RouteSpecFluent.java <==
package io.fabric8.knative.serving.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface RouteSpecFluent<A extends RouteSpecFluent<A>> extends Fluent<A>{
  public A addToTraffic(int index,TrafficTarget item);
  public A setToTraffic(int index,TrafficTarget item);
  public A addToTraffic(io.fabric8.knative.serving.v1.TrafficTarget... items);
  public A addAllToTraffic(Collection<TrafficTarget> items);
  public A removeFromTraffic(io.fabric8.knative.serving.v1.TrafficTarget... items);
  public A removeAllFromTraffic(Collection<TrafficTarget> items);
  public A removeMatchingFromTraffic(Predicate<TrafficTargetBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildTraffic instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<TrafficTarget> getTraffic();
  public List<TrafficTarget> buildTraffic();
  public TrafficTarget buildTraffic(int index);
  public TrafficTarget buildFirstTraffic();
  public TrafficTarget buildLastTraffic();
  public TrafficTarget buildMatchingTraffic(Predicate<TrafficTargetBuilder> predicate);
  public Boolean hasMatchingTraffic(Predicate<TrafficTargetBuilder> predicate);
  public A withTraffic(List<TrafficTarget> traffic);
  public A withTraffic(io.fabric8.knative.serving.v1.TrafficTarget... traffic);
  public Boolean hasTraffic();
  public RouteSpecFluent.TrafficNested<A> addNewTraffic();
  public RouteSpecFluent.TrafficNested<A> addNewTrafficLike(TrafficTarget item);
  public RouteSpecFluent.TrafficNested<A> setNewTrafficLike(int index,TrafficTarget item);
  public RouteSpecFluent.TrafficNested<A> editTraffic(int index);
  public RouteSpecFluent.TrafficNested<A> editFirstTraffic();
  public RouteSpecFluent.TrafficNested<A> editLastTraffic();
  public RouteSpecFluent.TrafficNested<A> editMatchingTraffic(Predicate<TrafficTargetBuilder> predicate);
  public interface TrafficNested<N> extends Nested<N>,TrafficTargetFluent<RouteSpecFluent.TrafficNested<N>>{
    public N and();
    public N endTraffic();
    
  }
  
}
